@@ -1,13 +1,19 @@
 from django.contrib.auth.base_user import AbstractBaseUser, BaseUserManager
 from django.db import models
-from django.utils import timezone
 
 import core.models
-from django.contrib.auth.models import UserManager, PermissionsMixin, Permission, Group
+from django.contrib.auth.models import PermissionsMixin, Permission, Group
 from compositefk.fields import CompositeForeignKey
 from django.utils.translation import gettext_lazy as _
 
+
 class Profile(AbstractBaseUser, core.models.Log, PermissionsMixin):
+    """
+    :Nome da classe/função: Profile
+    :descrição: Classe abstrata para as classes de login e que sobrescreve a base de usuário abstrata
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     username = models.CharField(max_length=200, unique=True)
     USERNAME_FIELD = 'username'
     is_staff = models.BooleanField(null=True, default=False)
@@ -61,6 +67,12 @@ class Profile(AbstractBaseUser, core.models.Log, PermissionsMixin):
 
 
 class Grupo(core.models.Log):
+    """
+    :Nome da classe/função: Grupo
+    :descrição: Classe de grupos de sistema de usuários
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nivel = models.IntegerField(null=True)
     nome = models.CharField(max_length=200, primary_key=True)
     nm_descritivo = models.CharField(max_length=200, null=True)
@@ -73,6 +85,12 @@ class Grupo(core.models.Log):
 
 
 class GrupoUser(core.models.Log):
+    """
+    :Nome da classe/função: GrupoUser
+    :descrição: Classe de relação de grupo com usuário de login
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     grupo = models.ForeignKey('usr.Grupo', on_delete=models.DO_NOTHING, null=True)
 
     usr_id = models.IntegerField(null=True)
